# Generated by Django 4.2.23 on 2026-02-24 11:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("custom_fields", "0006_add_filterable_to_customfield"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="customvalue",
            name="field",
        ),
        migrations.DeleteModel(
            name="CustomField",
        ),
        migrations.DeleteModel(
            name="CustomValue",
        ),
    ]
