# Generated by Django 4.2.24 on 2025-10-30 12:07

from django.db import migrations
from django.db import models


class Migration(migrations.Migration):

    dependencies = [
        ("custom_fields", "0005_rename_text_to_label"),
    ]

    operations = [
        migrations.AddField(
            model_name="customfield",
            name="filterable",
            field=models.BooleanField(
                default=False, verbose_name="Als Filter anbieten"
            ),
        ),
    ]
